@@ -20,6 +20,22 @@
 #include <am_defs.h>
 #include <amd.h>
 
+/* AIX requires this to be the first thing in the file. */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else /* not HAVE_ALLOCA_H */
+#  ifdef _AIX
+#pragma alloca
+#  else /* not _AIX */
+#   ifndef alloca
+  /* predefined by HP cc +Olibcalls */
+voidp alloca();
+#   endif /* not alloca */
+#  endif /* not _AIX */
+# endif /* not HAVE_ALLOCA_H */
+#endif /* not __GNUC__ */
+
 extern char *yytext;
 extern int yylineno;
 extern int yylex(void);
@@ -41,7 +57,7 @@ static char *header_section = NULL; /* start with no header section */
 #endif /* PARSE_DEBUG */
 
 
-#line 74 "../../amd/conf_parse.y"
+#line 90 "../../amd/conf_parse.y"
 typedef union {
 char *strtype;
 } YYSTYPE;
@@ -126,8 +142,8 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-    88,    88,    89,    90,    92,    93,    96,    97,   100,   103,
-   111,   112,   115,   125,   135,   145
+   104,   104,   105,   106,   108,   109,   112,   113,   116,   119,
+   127,   128,   131,   141,   151,   161
 };
 
 static const char * const yytname[] = {   "$","error","$illegal.","LEFT_BRACKET",
@@ -648,15 +664,15 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 88 "../../amd/conf_parse.y"
+#line 104 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; ;
     break;}
 case 3:
-#line 89 "../../amd/conf_parse.y"
+#line 105 "../../amd/conf_parse.y"
 { yydebug = PARSE_DEBUG; ;
     break;}
 case 10:
-#line 104 "../../amd/conf_parse.y"
+#line 120 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr, "sec_header1 = \"%s\"\n", yyvsp[-2].strtype);
@@ -664,7 +680,7 @@ case 10:
 		;
     break;}
 case 13:
-#line 116 "../../amd/conf_parse.y"
+#line 132 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -676,7 +692,7 @@ case 13:
 		;
     break;}
 case 14:
-#line 126 "../../amd/conf_parse.y"
+#line 142 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -688,7 +704,7 @@ case 14:
 		;
     break;}
 case 15:
-#line 136 "../../amd/conf_parse.y"
+#line 152 "../../amd/conf_parse.y"
 {
 		  if (yydebug)
 		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", yyvsp[-3].strtype, yyvsp[-1].strtype);
@@ -897,7 +913,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 149 "../../amd/conf_parse.y"
+#line 165 "../../amd/conf_parse.y"
 
 
 static int
